Get the coordinate reference system of a spatial object.
# S4 method for ANY
getCRS(x)# S4 method for geom
getCRS(x)
# S4 method for Spatial
getCRS(x)
# S4 method for sf
getCRS(x)
# S4 method for ppp
getCRS(x)
# S4 method for Raster
getCRS(x)
the object from which to extract the coordinate reference system.
The coordinate reference system of x given as proj4string.
Other getters: getExtent,
getHistory, getPoints,
getSubset, getTable,
getType, getWindow